<div id="edit-this-article-source">
    {{ edit_source | replace_local_to_server}}
</div>

# Installation and first chart

:::info
LiveCharts requires at least .Net framework 4.6.2 to work, the library supports Net core 3.1, 5.0 and 6.0, LiveCharts by default uses
SkiaSharp to draw any plot in the library.
:::

{{~ if wpf ~}}

Open visual studio 2022, select "Create a new project", then select the WPF Application template.

<p align="center">
  <img src="https://raw.githubusercontent.com/beto-rodriguez/LiveCharts2/master/docs/_assets/newwpf.png" />
</p>

Name the project and the solution WpfSample, and select .NET 6.0 as the framework, if the framework is not available for you, you can also use
.NET 5.0, .NET core 3.1 or .NET 4.6.2 or greater.

## Install from NuGet

Now install [LiveCharts from NuGet](https://www.nuget.org/packages/LiveChartsCore.SkiaSharpView.WPF). If you need more help to 
install a package from NuGet, please follow [this guide](https://docs.microsoft.com/en-us/nuget/consume-packages/install-use-packages-visual-studio).

> LiveChartsCore.SkiaSharpView.WPF

## Create a View Model

After the package is installed add a new class to your project as follows:

<pre><code>using LiveChartsCore;
using LiveChartsCore.SkiaSharpView;

namespace WpfSample
{
    public class ViewModel
    {
        public ISeries[] Series { get; set; } 
            = new ISeries[]
            {
                new LineSeries&lt;double>
                {
                    Values = new double[] { 2, 1, 3, 5, 3, 4, 6 },
                    Fill = null
                }
            };
    }
}</code></pre>

## Add the chart control to the UI

Finally go to the `MainWindow.xaml` file and add the LiveCharts namespace, don't forget to add also the namespace of your `ViewModel` class, 
then add a `CartesianChart` control and bind the `Series` property:

<pre><code>&lt;!-- mark -skip 3 -take 2 --&gt;
&lt;Window x:Class="MyApp"
    xmlns="http://schemas.microsoft.com/winfx/2006/xaml/presentation"
    xmlns:x="http://schemas.microsoft.com/winfx/2006/xaml" 
    xmlns:local="clr-namespace:WPFSample"
    xmlns:lvc="clr-namespace:LiveChartsCore.SkiaSharpView.WPF;assembly=LiveChartsCore.SkiaSharpView.WPF">

    &lt;Window.DataContext>
        &lt;local:ViewModel />&lt;!-- mark --&gt;
    &lt;/Window.DataContext>

    &lt;lvc:CartesianChart&lt;!-- mark --&gt;
        Series="{Binding Series}">&lt;!-- mark --&gt;
    &lt;/lvc:CartesianChart>&lt;!-- mark --&gt;

&lt;/Window>
</code></pre>

And that's it, start your application and you will see the chart in your main window.

{{~ end ~}}

{{~ if avalonia ~}}

Create a new Avalonia project and name the project and the solution AvaloniaSample, and select .NET 6.0 as the framework, if the framework is not 
available for you, you can also use .NET 5.0, .NET core 3.1 or .NET 4.6.2 or greater, if you need help to get started with Avalonia please see
the [Avalonia docs](https://github.com/AvaloniaUI/Avalonia#-getting-started).

## Install from NuGet

You can [get LiveCharts from NuGet](https://www.nuget.org/packages/LiveChartsCore.SkiaSharpView.Avalonia). If you need more help to 
install a package from NuGet, please follow [this guide](https://docs.microsoft.com/en-us/nuget/consume-packages/install-use-packages-visual-studio).

> LiveChartsCore.SkiaSharpView.Avalonia

## Create a View Model

After the package is installed add a new class to your project as follows:

<pre><code>using LiveChartsCore;
using LiveChartsCore.SkiaSharpView;

namespace AvaloniaSample
{
    public class ViewModel
    {
        public ISeries[] Series { get; set; } 
            = new ISeries[]
            {
                new LineSeries&lt;double>
                {
                    Values = new double[] { 2, 1, 3, 5, 3, 4, 6 },
                    Fill = null
                }
            };
    }
}</code></pre>

## Add the chart control to the UI

Finally go to the `MainWindow.axaml` file and add the LiveCharts namespace, don't forget to add also the namespace of your `ViewModel` class, 
then add a `CartesianChart` control and bind the `Series` property:

<pre><code>&lt;!-- mark -skip 3 -take 2 --&gt;
&lt;Window x:Class="MyApp"
    xmlns="https://github.com/avaloniaui"
    xmlns:x="http://schemas.microsoft.com/winfx/2006/xaml"
    xmlns:local="using:AvaloniaSample"
    xmlns:lvc="using:LiveChartsCore.SkiaSharpView.Avalonia">

    &lt;Window.DataContext>
        &lt;local:ViewModel />&lt;!-- mark --&gt;
    &lt;/Window.DataContext>

    &lt;lvc:CartesianChart&lt;!-- mark --&gt;
        Series="{Binding Series}">&lt;!-- mark --&gt;
    &lt;/lvc:CartesianChart>&lt;!-- mark --&gt;

&lt;/Window>
</code></pre>

And that's it, start your application and you will see the chart in your main window.

{{~ end ~}}

{{~ if winforms ~}}

Open visual studio 2022, select "Create a new project", then select the Windows Forms Application template.

<p align="center">
  <img src="https://raw.githubusercontent.com/beto-rodriguez/LiveCharts2/master/docs/_assets/newwf.png" />
</p>

Name the project and the solution WinFormsSample, and select .NET 6.0 as the framework, if the framework is not available for you, you can also use
.NET 5.0, .NET core 3.1 or .NET 4.6.2 or greater.

## Install from NuGet

Now install [LiveCharts from NuGet](https://www.nuget.org/packages/LiveChartsCore.SkiaSharpView.WinForms). If you need more help to 
install a package from NuGet, please follow [this guide](https://docs.microsoft.com/en-us/nuget/consume-packages/install-use-packages-visual-studio).

> Install-Package LiveChartsCore.SkiaSharpView.WinForms

After the package is installed you should see the LiveCharts controls in your toolbox, drag a new `CartesianChart` control from your toolbox to the 
`Form1` class.

If the control does not appear in your toolbox, try to rebuild your project and look for it again.

<p align="center">
  <img src="https://raw.githubusercontent.com/beto-rodriguez/LiveCharts2/master/docs/_assets/wf-designer.gif" />
</p>

Now go to the code behind of the `Form1` class and set the `Series` property as follows: 

<pre><code>using LiveChartsCore;
using LiveChartsCore.SkiaSharpView;

namespace WinFormsSample
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            cartesianChart1.Series = new ISeries[] // mark
            { // mark
                new LineSeries&lt;double> // mark
                { // mark
                    Values = new double[] { 2, 1, 3, 5, 3, 4, 6 }, // mark
                    Fill = null // mark
                } // mark
            }; // mark
        }
    }
}</code></pre>

And that's it, start your application and you will see the chart in your main window.

:::info
Notice that all the samples in this web site use an Model-View-* pattern, it helps us to build the samples for all the platforms faster,
you will find through the docs of this site, that we map the series property of the view model class to the control in the UI.
:::

{{~ end ~}}

{{~ if xamarin ~}}

:::info
This sample uses VisualStudio 2022, Xamarin 5.0 and the Flyout template, Xamarin is in constant evolution and there is a chance that something
has changed at the moment you are reading this, if this article is not useful enough, feel free to open a new issue to report it or create a PR
with a better sample.
:::

Open visual studio 2022, select "Create a new project", then select the Mobile App (Xamarin.Forms) template.

<p align="center">
  <img src="https://raw.githubusercontent.com/beto-rodriguez/LiveCharts2/master/docs/_assets/newwpf.png" />
</p>

Name the project and the solution XamarinSample, and select the Flyout template.

## Install from NuGet

Now in the XamarinSample project, install [LiveCharts from NuGet](https://www.nuget.org/packages/LiveChartsCore.SkiaSharpView.XamarinForms). If you need more help to 
install a package from NuGet, please follow [this guide](https://docs.microsoft.com/en-us/nuget/consume-packages/install-use-packages-visual-studio).

> Install-Package LiveChartsCore.SkiaSharpView.XamarinForms

## Create a View Model

After the package is installed, go to the `ViewModels` folder and add a new class as follows:

<pre><code>using LiveChartsCore;
using LiveChartsCore.SkiaSharpView;
using System.Collections.Generic;

namespace XamarinSample.ViewModels
{
    public class ChartViewModel
    {
        public ISeries[] Series { get; set; }
            = new ISeries[]
            {
                new LineSeries&lt;double>
                {
                    Values = new double[] { 2, 1, 3, 5, 3, 4, 6 },
                    Fill = null
                }
            };
    }
}</code></pre>

## Add the chart control to the UI

Now for simplicity, we will change the `ItemsPage.xaml` view in this template (Flyout) to display our chart `ChartViewModel`,
Go to the `Views` folder and then open the `ItemsPage.xaml`, add the LiveCharts namespace to the view and replace the content
of the `ItemsPage` only with a cartesian chart, bind the `Series` property to the `ChartViewModel.Series` property.

<pre><code>&lt;ContentPage x:Class="MyApp"
    xmlns="http://xamarin.com/schemas/2014/forms"
    xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
    xmlns:lvc="clr-namespace:LiveChartsCore.SkiaSharpView.Xamarin.Forms;assembly=LiveChartsCore.SkiaSharpView.XamarinForms">&lt;!-- mark --&gt;

    &lt;lvc:CartesianChart&lt;!-- mark --&gt;
        Series="{Binding Series}">&lt;!-- mark --&gt;
    &lt;/lvc:CartesianChart>&lt;!-- mark --&gt;

&lt;/ContentPage></code></pre>

Now in the code behind of your `ItemsPage`, set the `BindingContext` property to a new instance of the `ChartViewModel` class we created above.

<pre><code>using Xamarin.Forms;
using XamarinSample.ViewModels;

namespace XamarinSample.Views
{
    public partial class ItemsPage : ContentPage
    {
        public ItemsPage()
        {
            InitializeComponent();

            BindingContext = new ChartViewModel(); // mark
        }

        protected override void OnAppearing()
        {
            base.OnAppearing();
        }
    }
}</code></pre>

And that's it, when you app starts our chart will be displayed instead of the `ItemsPage` view.

<p align="center">
  <img src="https://raw.githubusercontent.com/beto-rodriguez/LiveCharts2/master/docs/_assets/xf-result.gif" />
</p>=

{{~ end ~}}

{{~ if uwp ~}}

Open visual studio 2022, select "Create a new project", then select the Blank App (Universal Windows) template.

<p align="center">
  <img src="https://raw.githubusercontent.com/beto-rodriguez/LiveCharts2/master/docs/_assets/newuwp.png" />
</p>

Name the project and the solution UwpSample, and use the default target version.

## Install from NuGet

Now install [LiveCharts from NuGet](https://www.nuget.org/packages/LiveChartsCore.SkiaSharpView.UWP). If you need more help to 
install a package from NuGet, please follow [this guide](https://docs.microsoft.com/en-us/nuget/consume-packages/install-use-packages-visual-studio).

> LiveChartsCore.SkiaSharpView.UWP

## Create a View Model

After the package is installed add a new class to your project as follows:

<pre><code>using LiveChartsCore;
using LiveChartsCore.SkiaSharpView;

namespace UwpSample
{
    public class ViewModel
    {
        public ISeries[] Series { get; set; } 
            = new ISeries[]
            {
                new LineSeries&lt;double>
                {
                    Values = new double[] { 2, 1, 3, 5, 3, 4, 6 },
                    Fill = null
                }
            };
    }
}</code></pre>

## Add the chart control to the UI

Finally go to the `MainPage.xaml` file and add the LiveCharts namespace, don't forget to add also the namespace of your `ViewModel` class, 
then add a `CartesianChart` control and bind the `Series` property:

<pre><code>&lt;!-- mark -skip 3 -take 2 --&gt;
&lt;Window x:Class="MyApp"
    xmlns="http://schemas.microsoft.com/winfx/2006/xaml/presentation"
    xmlns:x="http://schemas.microsoft.com/winfx/2006/xaml" 
    xmlns:local="using:UwpSample"
    xmlns:lvc="using:LiveChartsCore.SkiaSharpView.UWP">

    &lt;Page.DataContext>
        &lt;local:ViewModel />&lt;!-- mark --&gt;
    &lt;/Page.DataContext>

    &lt;lvc:CartesianChart&lt;!-- mark --&gt;
        Series="{Binding Series}">&lt;!-- mark --&gt;
    &lt;/lvc:CartesianChart>&lt;!-- mark --&gt;

&lt;/Window>
</code></pre>

And that's it, start your application and you will see the chart in your main page.

{{~ end ~}}

{{~ if winui ~}}

Open visual studio 2022, select "Create a new project", then select the Blank App, Packed with WAP (WinUI 3 In Desktop) template.

<p align="center">
  <img src="https://raw.githubusercontent.com/beto-rodriguez/LiveCharts2/master/docs/_assets/newwinui.png" />
</p>

Name the project and the solution WinUISample, and use the default target version.

## Install from NuGet

Now install [LiveCharts from NuGet](https://www.nuget.org/packages/LiveChartsCore.SkiaSharpView.WinUI). If you need more help to 
install a package from NuGet, please follow [this guide](https://docs.microsoft.com/en-us/nuget/consume-packages/install-use-packages-visual-studio).

> LiveChartsCore.SkiaSharpView.WinUI

## Create a View Model

After the package is installed add a new class to your project as follows:

<pre><code>using LiveChartsCore;
using LiveChartsCore.SkiaSharpView;

namespace WinUISample
{
    public class ViewModel
    {
        public &lt;ISeries[] Series { get; set; } 
            = new ISeries[]
            {
                new LineSeries&lt;double>
                {
                    Values = new double[] { 2, 1, 3, 5, 3, 4, 6 },
                    Fill = null
                }
            };
    }
}</code></pre>

## Add the chart control to the UI

Finally go to the `MainWindow.xaml` file and add the LiveCharts namespace, don't forget to add also the namespace of your `ViewModel` class, 
then add a `CartesianChart` control and bind the `Series` property:

<pre><code>&lt;!-- mark -skip 3 -take 2 --&gt;
&lt;Window x:Class="WinUISample.MainWindow"
    xmlns="http://schemas.microsoft.com/winfx/2006/xaml/presentation"
    xmlns:x="http://schemas.microsoft.com/winfx/2006/xaml" 
    xmlns:local="using:App3"
    xmlns:lvc="using:LiveChartsCore.SkiaSharpView.WinUI">

    &lt;Window.DataContext>
        &lt;local:ViewModel />&lt;!-- mark --&gt;
    &lt;/Window.DataContext>

    &lt;lvc:CartesianChart&lt;!-- mark --&gt;
        Series="{Binding Series}">&lt;!-- mark --&gt;
    &lt;/lvc:CartesianChart>&lt;!-- mark --&gt;

&lt;/Window></code></pre>

And that's it, start your application and you will see the chart in your main window.

{{~ end ~}}

{{~ if blazor ~}}

Open visual studio 2022, select "Create a new project", then select the Blazor WebAssembly App template.

<p align="center">
  <img src="https://raw.githubusercontent.com/beto-rodriguez/LiveCharts2/master/docs/_assets/newblazor.png" />
</p>

Name the project and the solution BlazorSample, and select .NET 6.0 as the framework, if the framework is not available for you, you can also use
.NET 5.0.

## Install from NuGet

Now install [LiveCharts from NuGet](https://www.nuget.org/packages/LiveChartsCore.SkiaSharpView.Blazor). If you need more help to 
install a package from NuGet, please follow [this guide](https://docs.microsoft.com/en-us/nuget/consume-packages/install-use-packages-visual-studio).

> LiveChartsCore.SkiaSharpView.Blazor

Now go to the `Pages` folder and open the `Index.razor` view, add the necessary using statements to import the LiveCharts components and objects,
add a `CartesianChart` component to your view and define a private field for the series to display in our chart, finally bind the field 
to the `CartesianChart.Series` property. 

<pre><code>@page "/"
@using LiveChartsCore
@using LiveChartsCore.SkiaSharpView
@using LiveChartsCore.SkiaSharpView.Blazor

&lt;PageTitle>Index</PageTitle>

&lt;h1>Hello, world!</h1>

Welcome to your new app.

&lt;SurveyPrompt Title="How is Blazor working for you?" />

&lt;CartesianChart&lt;!-- mark --&gt;
	Series="_series">&lt;!-- mark --&gt;
&lt;/CartesianChart>&lt;!-- mark --&gt;</code></pre>

<pre><code>@code {
    private ISeries[] _series = // mark
        new ISeries[] // mark
        { // mark
            new LineSeries&lt;double> // mark
            { // mark
                Values = new double[] { 2, 1, 3, 5, 3, 4, 6 }, // mark
                Fill = null // mark
            } // mark
        }; // mark
}</code></pre>

And that's it, start your application and you will see the chart the app starts.

{{~ end ~}}

{{~ if maui ~}}

:::info
Maui keeps evolving and changing in every preview, this documentation might be improved in the future as Maui matures. 
:::

## Install from NuGet

Now install [LiveCharts from NuGet](https://www.nuget.org/packages/LiveChartsCore.SkiaSharpView.Maui). If you need more help to 
install a package from NuGet, please follow [this guide](https://docs.microsoft.com/en-us/nuget/consume-packages/install-use-packages-visual-studio).

> LiveChartsCore.SkiaSharpView.Maui

## Create a View Model

After the package is installed add a new class to your project as follows:

<pre><code>using LiveChartsCore;
using LiveChartsCore.SkiaSharpView;

namespace MauiSample
{
    public class ViewModel
    {
        public &lt;ISeries[] Series { get; set; } 
            = new ISeries[]
            {
                new LineSeries&lt;double>
                {
                    Values = new double[] { 2, 1, 3, 5, 3, 4, 6 },
                    Fill = null
                }
            };
    }
}</code></pre>

## Add the chart control to the UI

Finally add the LiveCharts namespace, don't forget to add also the namespace of your `ViewModel` class, 
then add a `CartesianChart` control and bind the `Series` property.

<pre><code>&lt;!-- mark -skip 4 -take 2 --&gt;
&lt;?xml version="1.0" encoding="utf-8" ?>
&lt;ContentPage x:Class="MauiSample.Lines.Basic.View"
             xmlns="http://schemas.microsoft.com/dotnet/2021/maui"
             xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
             xmlns:local="clr-namespace:MauiSample;assembly=MauiSample"
             xmlns:lvc="clr-namespace:LiveChartsCore.SkiaSharpView.Maui;assembly=LiveChartsCore.SkiaSharpView.Maui">
    &lt;ContentPage.BindingContext>
        &lt;local:ViewModel/>
    &lt;/ContentPage.BindingContext>
	&lt;ContentPage.Content>
        &lt;Grid>
            &lt;lvc:CartesianChart&lt;!-- mark --&gt;
                Series="{Binding Series}">&lt;!-- mark --&gt;
            &lt;/lvc:CartesianChart>&lt;!-- mark --&gt;
        &lt;/Grid>
    &lt;/ContentPage.Content>
&lt;/ContentPage></code></pre>

And that's it, start your application and you will see the chart.

{{~ end ~}}

## Configure themes and mappers (Optional)

Optionally you could configure LiveCharts to add a theme or a custom mapper, add the following code when your
application starts:

{{~ if avalonia ~}}

Go to the `Solution Explorer` and browse for `App.axaml.cs` file, then add the settings you need:

<pre><code>using Avalonia;
using Avalonia.Controls.ApplicationLifetimes;
using Avalonia.Markup.Xaml;
using LiveChartsCore;// mark
using LiveChartsCore.SkiaSharpView;// mark

namespace AvaloniaSample
{
    public class App : Application
    {
        public override void Initialize()
        {
            AvaloniaXamlLoader.Load(this);

            LiveCharts.Configure(config => // mark
                config // mark
                    // registers SkiaSharp as the library backend
                    // REQUIRED unless you build your own
                    .AddSkiaSharp() // mark

                    // adds the default supported types
                    // OPTIONAL but highly recommend
                    .AddDefaultMappers() // mark

                    // select a theme, default is Light
                    // OPTIONAL
                    //.AddDarkTheme()
                    .AddLightTheme() // mark

                    // finally register your own mappers
                    // you can learn more about mappers at:
                    // ToDo add website link...
                    .HasMap&lt;City>((city, point) =>// mark
                    {// mark
                        point.PrimaryValue = city.Population;// mark
                        point.SecondaryValue = point.Context.Index;// mark
                    })// mark
                    // .HasMap&lt;Foo>( .... )// mark
                    // .HasMap&lt;Bar>( .... )// mark
                );
        }

        public override void OnFrameworkInitializationCompleted()
        {
            if (ApplicationLifetime is IClassicDesktopStyleApplicationLifetime desktop)
            {
                desktop.MainWindow = new MainWindow();
            }

            base.OnFrameworkInitializationCompleted();
        }
    }
}
</code></pre>
{{~ end ~}}

{{~ if wpf ~}}
Go to the `Solution Explorer` and browse for `App.xaml.cs` file, then override the `OnStartup` method as follows.

<pre><code>using System.Windows;
using LiveChartsCore;// mark
using LiveChartsCore.SkiaSharpView;// mark

namespace WPFSample
{
    public partial class App : Application
    {
        protected override void OnStartup(StartupEventArgs e)
        {
            base.OnStartup(e);

            LiveCharts.Configure(config =>// mark
                config// mark
                    // registers SkiaSharp as the library backend
                    // REQUIRED unless you build your own
                    .AddSkiaSharp()// mark

                    // adds the default supported types
                    // OPTIONAL but highly recommend
                    .AddDefaultMappers()// mark

                    // select a theme, default is Light
                    // OPTIONAL
                    //.AddDarkTheme()
                    .AddLightTheme()// mark

                    // finally register your own mappers
                    // you can learn more about mappers at:
                    // ToDo add website link...
                    .HasMap&lt;City>((city, point) =>// mark
                    {// mark
                        point.PrimaryValue = city.Population;// mark
                        point.SecondaryValue = point.Context.Index;// mark
                    })// mark
                    // .HasMap&lt;Foo>( .... )// mark
                    // .HasMap&lt;Bar>( .... )// mark
                );
        }
    }
}
</code></pre>
{{~ end ~}}

{{~ if xamarin ~}}
Go to the `Solution Explorer` and browse for `App.xaml.cs` file, then edit the `OnStart` method as follows.

<pre><code>using Xamarin.Forms;
using LiveChartsCore;// mark
using LiveChartsCore.SkiaSharpView;// mark

namespace XamarinSample
{
    public partial class App : Application
    {

        public App()
        {
            InitializeComponent();

            MainPage = new AppShell();
        }

        protected override void OnStart()
        {
            LiveCharts.Configure(config =>// mark
                config// mark
                    // registers SkiaSharp as the library backend
                    // REQUIRED unless you build your own
                    .AddSkiaSharp()// mark

                    // adds the default supported types
                    // OPTIONAL but highly recommend
                    .AddDefaultMappers()// mark

                    // select a theme, default is Light
                    // OPTIONAL
                    //.AddDarkTheme()
                    .AddLightTheme()// mark

                    // finally register your own mappers
                    // you can learn more about mappers at:
                    // ToDo add website link...
                    .HasMap&lt;City>((city, point) =>// mark
                    {// mark
                        point.PrimaryValue = city.Population;// mark
                        point.SecondaryValue = point.Context.Index;// mark
                    })// mark
                    // .HasMap&lt;Foo>( .... )// mark
                    // .HasMap&lt;Bar>( .... )// mark
                );// mark
        }

        protected override void OnSleep()
        {
        }

        protected override void OnResume()
        {
        }
    }
}
</code></pre>

{{~ end ~}}

{{~ if winforms ~}}
Go to the `Solution Explorer` and browse for `Program.cs` file, then edit the it as follows.

<pre><code>using System;
using System.Windows.Forms;
using LiveChartsCore;// mark
using LiveChartsCore.SkiaSharpView;// mark

namespace WinFormsSample
{
    static class Program
    {
        [STAThread]
        static void Main()
        {
            _ = Application.SetHighDpiMode(HighDpiMode.SystemAware);
            Application.EnableVisualStyles();
            Application.SetCompatibleTextRenderingDefault(false);
            Application.Run(new Form1());

            LiveCharts.Configure(config =>// mark
                config// mark
                    // registers SkiaSharp as the library backend
                    // REQUIRED unless you build your own
                    .AddSkiaSharp()// mark

                    // adds the default supported types
                    // OPTIONAL but highly recommend
                    .AddDefaultMappers()// mark

                    // select a theme, default is Light
                    // OPTIONAL
                    //.AddDarkTheme()
                    .AddLightTheme()// mark

                    // finally register your own mappers
                    // you can learn more about mappers at:
                    // ToDo add website link...
                    .HasMap&lt;City>((city, point) =>// mark
                    {// mark
                        point.PrimaryValue = city.Population;// mark
                        point.SecondaryValue = point.Context.Index;// mark
                    })// mark
                    // .HasMap&lt;Foo>( .... )// mark
                    // .HasMap&lt;Bar>( .... )// mark
                );// mark
        }
    }
}
</code></pre>
{{~ end ~}}

{{~ if uwp ~}}
Go to the `Solution Explorer` and browse for `App.xaml.cs` file, then edit the it as follows.

<pre><code>using System;
using Windows.ApplicationModel;
using Windows.ApplicationModel.Activation;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Navigation;
using LiveChartsCore;// mark
using LiveChartsCore.SkiaSharpView;// mark

namespace App4
{
    /// &lt;summary>
    /// Provides application-specific behavior to supplement the default Application class.
    /// &lt;/summary>
    sealed partial class App : Application
    {
        /// &lt;summary>
        /// Initializes the singleton application object.  This is the first line of authored code
        /// executed, and as such is the logical equivalent of main() or WinMain().
        /// &lt;/summary>
        public App()
        {
            this.InitializeComponent();
            this.Suspending += OnSuspending;
        }

        /// &lt;summary>
        /// Invoked when the application is launched normally by the end user.  Other entry points
        /// will be used such as when the application is launched to open a specific file.
        /// &lt;/summary>
        /// &lt;param name="e">Details about the launch request and process.&lt;/param>
        protected override void OnLaunched(LaunchActivatedEventArgs e)
        {
            Frame rootFrame = Window.Current.Content as Frame;

            // Do not repeat app initialization when the Window already has content,
            // just ensure that the window is active
            if (rootFrame == null)
            {
                // Create a Frame to act as the navigation context and navigate to the first page
                rootFrame = new Frame();

                rootFrame.NavigationFailed += OnNavigationFailed;

                if (e.PreviousExecutionState == ApplicationExecutionState.Terminated)
                {
                    //TODO: Load state from previously suspended application
                }

                // Place the frame in the current Window
                Window.Current.Content = rootFrame;
            }

            if (e.PrelaunchActivated == false)
            {
                if (rootFrame.Content == null)
                {
                    // When the navigation stack isn't restored navigate to the first page,
                    // configuring the new page by passing required information as a navigation
                    // parameter
                    rootFrame.Navigate(typeof(MainPage), e.Arguments);
                }
                // Ensure the current window is active
                Window.Current.Activate();
            }

            LiveCharts.Configure(config =>// mark
                config// mark
                    // registers SkiaSharp as the library backend
                    // REQUIRED unless you build your own
                    .AddSkiaSharp()// mark

                    // adds the default supported types
                    // OPTIONAL but highly recommend
                    .AddDefaultMappers()// mark

                    // select a theme, default is Light
                    // OPTIONAL
                    //.AddDarkTheme()
                    .AddLightTheme()// mark

                    // finally register your own mappers
                    // you can learn more about mappers at:
                    // ToDo add website link...
                    .HasMap&lt;City>((city, point) =>// mark
                    {// mark
                        point.PrimaryValue = city.Population;// mark
                        point.SecondaryValue = point.Context.Index;// mark
                    })// mark
                    // .HasMap&lt;Foo>( .... )// mark
                    // .HasMap&lt;Bar>( .... )// mark
                );// mark
        }

        /// &lt;summary>
        /// Invoked when Navigation to a certain page fails
        /// &lt;/summary>
        /// &lt;param name="sender">The Frame which failed navigation&lt;/param>
        /// &lt;param name="e">Details about the navigation failure&lt;/param>
        void OnNavigationFailed(object sender, NavigationFailedEventArgs e)
        {
            throw new Exception("Failed to load Page " + e.SourcePageType.FullName);
        }

        /// &lt;summary>
        /// Invoked when application execution is being suspended.  Application state is saved
        /// without knowing whether the application will be terminated or resumed with the contents
        /// of memory still intact.
        /// &lt;/summary>
        /// &lt;param name="sender">The source of the suspend request.&lt;/param>
        /// &lt;param name="e">Details about the suspend request.&lt;/param>
        private void OnSuspending(object sender, SuspendingEventArgs e)
        {
            var deferral = e.SuspendingOperation.GetDeferral();
            //TODO: Save application state and stop any background activity
            deferral.Complete();
        }
    }
}</code></pre>
{{~ end ~}}

{{~ if winui ~}}
Go to the `Solution Explorer` and browse for `App.xaml.cs` file, then edit the it as follows.

<pre><code>using Microsoft.UI.Xaml;
using LiveChartsCore;// mark
using LiveChartsCore.SkiaSharpView;// mark

// To learn more about WinUI, the WinUI project structure,
// and more about our project templates, see: http://aka.ms/winui-project-info.

namespace App5
{
    /// &lt;summary>
    /// Provides application-specific behavior to supplement the default Application class.
    /// &lt;/summary>
    public partial class App : Application
    {
        /// &lt;summary>
        /// Initializes the singleton application object.  This is the first line of authored code
        /// executed, and as such is the logical equivalent of main() or WinMain().
        /// &lt;/summary>
        public App()
        {
            this.InitializeComponent();
        }

        /// &lt;summary>
        /// Invoked when the application is launched normally by the end user.  Other entry points
        /// will be used such as when the application is launched to open a specific file.
        /// &lt;/summary>
        /// &lt;param name="args">Details about the launch request and process.&lt;/param>
        protected override void OnLaunched(Microsoft.UI.Xaml.LaunchActivatedEventArgs args)
        {
            m_window = new MainWindow();
            m_window.Activate();

            LiveCharts.Configure(config =>// mark
                config// mark
                    // registers SkiaSharp as the library backend
                    // REQUIRED unless you build your own
                    .AddSkiaSharp()// mark

                    // adds the default supported types
                    // OPTIONAL but highly recommend
                    .AddDefaultMappers()// mark

                    // select a theme, default is Light
                    // OPTIONAL
                    //.AddDarkTheme()
                    .AddLightTheme()// mark

                    // finally register your own mappers
                    // you can learn more about mappers at:
                    // ToDo add website link...
                    .HasMap&lt;City>((city, point) =>// mark
                    {// mark
                        point.PrimaryValue = city.Population;// mark
                        point.SecondaryValue = point.Context.Index;// mark
                    })// mark
                    // .HasMap&lt;Foo>( .... )// mark
                    // .HasMap&lt;Bar>( .... )// mark
                );// mark
        }

        private Window m_window;
    }
}</code></pre>
{{~ end ~}}

{{~ if blazor ~}}

Add the following code where the app starts...
// ToDo: find where is that point in Blazor-wasm...

<pre><code>using LiveChartsCore;// mark
using LiveChartsCore.SkiaSharpView;// mark

LiveCharts.Configure(config =>// mark
    config// mark
        // registers SkiaSharp as the library backend
        // REQUIRED unless you build your own
        .AddSkiaSharp()// mark

        // adds the default supported types
        // OPTIONAL but highly recommend
        .AddDefaultMappers()// mark

        // select a theme, default is Light
        // OPTIONAL
        //.AddDarkTheme()
        .AddLightTheme()// mark

        // finally register your own mappers
        // you can learn more about mappers at:
        // ToDo add website link...
        .HasMap&lt;City>((city, point) =>// mark
        {// mark
            point.PrimaryValue = city.Population;// mark
            point.SecondaryValue = point.Context.Index;// mark
        })// mark
        // .HasMap&lt;Foo>( .... )// mark
        // .HasMap&lt;Bar>( .... )// mark
    );// mark</code></pre>
{{~ end ~}}

{{~ if maui ~}}
Go to the `Solution Explorer` and browse for `App.xaml.cs` file, then edit the it as follows.

<pre><code>using Application = Microsoft.Maui.Controls.Application;
using LiveChartsCore;// mark
using LiveChartsCore.SkiaSharpView;// mark

namespace MauiSample
{
    public partial class App : Application
    {
        public App()
        {
            InitializeComponent();

            MainPage = new AppShell();

            LiveCharts.Configure(config =>// mark
                config// mark
                    // registers SkiaSharp as the library backend
                    // REQUIRED unless you build your own
                    .AddSkiaSharp()// mark

                    // adds the default supported types
                    // OPTIONAL but highly recommend
                    .AddDefaultMappers()// mark

                    // select a theme, default is Light
                    // OPTIONAL
                    //.AddDarkTheme()
                    .AddLightTheme()// mark

                    // finally register your own mappers
                    // you can learn more about mappers at:
                    // ToDo add website link...
                    .HasMap&lt;City>((city, point) =>// mark
                    {// mark
                        point.PrimaryValue = city.Population;// mark
                        point.SecondaryValue = point.Context.Index;// mark
                    })// mark
                    // .HasMap&lt;Foo>( .... )// mark
                    // .HasMap&lt;Bar>( .... )// mark
                );// mark
        }
    }
}</code></pre>
{{~ end ~}}